@@ -1,7 +1,7 @@
 package IPC::System::Options;
 
-our $DATE = '2017-03-09'; # DATE
-our $VERSION = '0.30'; # VERSION
+our $DATE = '2017-04-09'; # DATE
+our $VERSION = '0.31'; # VERSION
 
 use strict;
 use warnings;
@@ -316,7 +316,7 @@ sub _system_or_readpipe_or_run {
     if ($exit_code) {
         if ($opts->{log} || $opt_die) {
             my $msg = sprintf(
-                "%s(%s) failed: %s (%s)%s%s",
+                "%s(%s) failed: %s (%s)%s%s%s",
                 $which,
                 join(" ", @args),
                 defined $extra_error ? "" : $exit_code,
@@ -373,7 +373,7 @@ IPC::System::Options - Perl's system() and readpipe/qx replacement, with options
 
 =head1 VERSION
 
-This document describes version 0.30 of IPC::System::Options (from Perl distribution IPC-System-Options), released on 2017-03-09.
+This document describes version 0.31 of IPC::System::Options (from Perl distribution IPC-System-Options), released on 2017-04-09.
 
 =head1 SYNOPSIS
 
